@@ -38,4 +38,10 @@ public interface TdTasksWidgetService extends RemoteService {
 	 * @throws Exception
 	 */
 	List<TdJobModel> getListJobForTaskId(String taskId) throws Exception;
+
+	/**
+	 * @param debug
+	 * @param tabularResourceId
+	 */
+	void setDegubTabularResource(boolean debug, String tabularResourceId);
 }
